==> igniteui-webcomponents-core-3.5.0.tgz: package/esm5/lib/WebBaseEventArgsDetailDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebBaseEventArgsDetailDescription } from "./WebBaseEventArgsDetailDescription";
/**
 * @hidden
 */
var WebBaseEventArgsDetailDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(WebBaseEventArgsDetailDescriptionMetadata, _super);
    function WebBaseEventArgsDetailDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebBaseEventArgsDetailDescriptionMetadata.b = function (a) {
        if (WebBaseEventArgsDetailDescriptionMetadata.a == null) {
            WebBaseEventArgsDetailDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebBaseEventArgsDetailDescriptionMetadata.c(WebBaseEventArgsDetailDescriptionMetadata.a);
        }
        if (a.j(WebBaseEventArgsDetailDescriptionMetadata.a)) {
            return;
        }
        a.y(WebBaseEventArgsDetailDescriptionMetadata.a);
    };
    WebBaseEventArgsDetailDescriptionMetadata.c = function (a) {
        a.item("__qualifiedNameTS", "String:BaseEventArgsDetail");
        a.item("__packageNameWC", "String:grids");
        a.item("__isPlainObject", "Boolean");
        a.item("Owner", "Unknown");
    };
    WebBaseEventArgsDetailDescriptionMetadata.d = function (a) {
        WebBaseEventArgsDetailDescriptionMetadata.b(a);
        a.aa("WebBaseEventArgsDetail", function () { return new WebBaseEventArgsDetailDescription(); });
        a.z("WebBaseEventArgsDetail", WebBaseEventArgsDetailDescriptionMetadata.a);
    };
    WebBaseEventArgsDetailDescriptionMetadata.$t = markType(WebBaseEventArgsDetailDescriptionMetadata, 'WebBaseEventArgsDetailDescriptionMetadata');
    WebBaseEventArgsDetailDescriptionMetadata.a = null;
    return WebBaseEventArgsDetailDescriptionMetadata;
}(Base));
export { WebBaseEventArgsDetailDescriptionMetadata };

==> igniteui-webcomponents-core-4.2.5.tgz: package/esm5/lib/WebBaseEventArgsDetailDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebBaseEventArgsDetailDescription } from "./WebBaseEventArgsDetailDescription";
/**
 * @hidden
 */
var WebBaseEventArgsDetailDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(WebBaseEventArgsDetailDescriptionMetadata, _super);
    function WebBaseEventArgsDetailDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebBaseEventArgsDetailDescriptionMetadata.b = function (a) {
        if (WebBaseEventArgsDetailDescriptionMetadata.a == null) {
            WebBaseEventArgsDetailDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebBaseEventArgsDetailDescriptionMetadata.c(WebBaseEventArgsDetailDescriptionMetadata.a);
        }
        if (a.k(WebBaseEventArgsDetailDescriptionMetadata.a)) {
            return;
        }
        a.aa(WebBaseEventArgsDetailDescriptionMetadata.a);
    };
    WebBaseEventArgsDetailDescriptionMetadata.c = function (a) {
        a.item("__qualifiedNameTS", "String:BaseEventArgsDetail");
        a.item("__packageNameWC", "String:grids");
        a.item("__skipModuleRegisterWebComponents", "Boolean");
        a.item("__importOverrideWebComponents", "String:igniteui-webcomponents-grids/grids/combined");
        a.item("__importTypesWebComponents", "String:igniteui-webcomponents-grids/grids");
        a.item("__isPlainObject", "Boolean");
        a.item("__skipSuffix", "Boolean");
        a.item("Owner", "Unknown");
    };
    WebBaseEventArgsDetailDescriptionMetadata.d = function (a) {
        WebBaseEventArgsDetailDescriptionMetadata.b(a);
        a.ac("WebBaseEventArgsDetail", function () { return new WebBaseEventArgsDetailDescription(); });
        a.ab("WebBaseEventArgsDetail", WebBaseEventArgsDetailDescriptionMetadata.a);
    };
    WebBaseEventArgsDetailDescriptionMetadata.$t = markType(WebBaseEventArgsDetailDescriptionMetadata, 'WebBaseEventArgsDetailDescriptionMetadata');
    WebBaseEventArgsDetailDescriptionMetadata.a = null;
    return WebBaseEventArgsDetailDescriptionMetadata;
}(Base));
export { WebBaseEventArgsDetailDescriptionMetadata };
